==> aws-java-sdk-waf-1.10.64-sources.jar: com/amazonaws/services/waf/model/transform/IPSetUpdateJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.waf.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.waf.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * IPSetUpdateMarshaller
 */
public class IPSetUpdateJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(IPSetUpdate iPSetUpdate, SdkJsonGenerator jsonGenerator) {
        if (iPSetUpdate == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (iPSetUpdate.getAction() != null) {
                jsonGenerator.writeFieldName("Action").writeValue(
                        iPSetUpdate.getAction());
            }
            if (iPSetUpdate.getIPSetDescriptor() != null) {
                jsonGenerator.writeFieldName("IPSetDescriptor");
                IPSetDescriptorJsonMarshaller.getInstance().marshall(
                        iPSetUpdate.getIPSetDescriptor(), jsonGenerator);
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static IPSetUpdateJsonMarshaller instance;

    public static IPSetUpdateJsonMarshaller getInstance() {
        if (instance == null)
            instance = new IPSetUpdateJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-waf-1.10.67-sources.jar: com/amazonaws/services/waf/model/transform/IPSetUpdateJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.waf.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.waf.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * IPSetUpdateMarshaller
 */
public class IPSetUpdateJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(IPSetUpdate iPSetUpdate,
            StructuredJsonGenerator jsonGenerator) {

        if (iPSetUpdate == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (iPSetUpdate.getAction() != null) {
                jsonGenerator.writeFieldName("Action").writeValue(
                        iPSetUpdate.getAction());
            }
            if (iPSetUpdate.getIPSetDescriptor() != null) {
                jsonGenerator.writeFieldName("IPSetDescriptor");
                IPSetDescriptorJsonMarshaller.getInstance().marshall(
                        iPSetUpdate.getIPSetDescriptor(), jsonGenerator);
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static IPSetUpdateJsonMarshaller instance;

    public static IPSetUpdateJsonMarshaller getInstance() {
        if (instance == null)
            instance = new IPSetUpdateJsonMarshaller();
        return instance;
    }

}
